==> ejc-zdsstore-api-3.0.0-20231224.063958-32-sources.jar: com/ejianc/business/zdsstore/vo/ReturnGoodsExportVO.java <==
package com.ejianc.business.zdsstore.vo;


import java.math.BigDecimal;

/**
 * 材料退货表
 * 
 * @author generator
 * 
 */
public class ReturnGoodsExportVO {
    private static final long serialVersionUID = 1L;
    
    private String billState; // 单据状态
    private String billCode; // 出库编号
    private String outDate; // 出库日期
    private String projectName; // 出库项目名称
    private String storeName; // 出库仓库名称
    private String contractName; // 合同名称
    private String supplierName; // 供应商名称
    private BigDecimal returnMny; // 退货金额
    private String employeeName; // 经办人
    private String materialNames; // 出库物资名称集合

    public String getBillState() {
        return billState;
    }

    public void setBillState(String billState) {
        this.billState = billState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getOutDate() {
        return outDate;
    }

    public void setOutDate(String outDate) {
        this.outDate = outDate;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public BigDecimal getReturnMny() {
        return returnMny;
    }

    public void setReturnMny(BigDecimal returnMny) {
        this.returnMny = returnMny;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
}

==> ejc-zdsstore-api-3.0.0-20240109.124832-94-sources.jar: com/ejianc/business/zdsstore/vo/ReturnGoodsExportVO.java <==
package com.ejianc.business.zdsstore.vo;


import java.math.BigDecimal;

/**
 * 材料退货表
 * 
 * @author generator
 * 
 */
public class ReturnGoodsExportVO {
    private static final long serialVersionUID = 1L;
    
    private String billState; // 单据状态
    private String billCode; // 出库编号
    private String outDate; // 出库日期
    private String projectName; // 出库项目名称
    private String storeName; // 出库仓库名称
    private String contractName; // 合同名称
    private String contractCode; //合同编码
    private String supplierName; // 供应商名称
    private BigDecimal returnMny; // 退货金额
    private String employeeName; // 经办人
    private String materialNames; // 出库物资名称集合

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getBillState() {
        return billState;
    }

    public void setBillState(String billState) {
        this.billState = billState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getOutDate() {
        return outDate;
    }

    public void setOutDate(String outDate) {
        this.outDate = outDate;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public BigDecimal getReturnMny() {
        return returnMny;
    }

    public void setReturnMny(BigDecimal returnMny) {
        this.returnMny = returnMny;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
}
